@@ -6,6 +6,7 @@ from wellets_cli.commands.accumulation import accumulation
 from wellets_cli.commands.asset import asset
 from wellets_cli.commands.config import config
 from wellets_cli.commands.currency import currency
+from wellets_cli.commands.investment import investment
 from wellets_cli.commands.login import login
 from wellets_cli.commands.portfolio import portfolio
 from wellets_cli.commands.register import register
@@ -39,5 +40,6 @@ def main():  # pragma: no cover
     cli.add_command(transfer)
     cli.add_command(asset)
     cli.add_command(register)
+    cli.add_command(investment)
 
     cli()
